==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Η εγγραφή βίντεο είναι σε εξέλιξη. Να κλείσει το παράθυρο;</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Φωτογραφία</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Αλλαγή Καμερών</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Δεν έχετε άδεια πρόσβασης στον φάκελο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Μη έγκυρος φάκελος</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Βασικό</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Τοποθεσία φακέλου</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Γρήγορη λειτουργία</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Χρονοκαθυστέρηση</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Φορμά Εξόδου</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 τμχ</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 τμχ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Το Camera είναι ένα εργαλείο λήψης και εγγραφής φωτογραφιών και βίντεο, με τη χρήση της κάμερας του υπολογιστή σας.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Το αρχείο δεν αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Αποθήκευση σε:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Φωτογραφία:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ρυθμίσεις ανάλυσεις</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ανάλυση:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Φωτογραφίες:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Ήχοι επίδρασης</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Λεπτομερής λειτουργία</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Φλασχλιτ</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Γραμμές πεδίου</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Γραμμές 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Γραμμές 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Μέγιστη ανάλυση:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Λήξη εγγραφής</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Εμφάνιση συντομεύσεων</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Ακύρωση λήψης φωτογραφιών</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Μενού περιβάλλοντος</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Λήψη φωτογραφίας</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Εγγραφή βίντεο</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Ακύρωση λήψης φωτογραφιών</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Κανονικό</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Εντονό</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Θερμό</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Ψυχρό</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Ρετρό</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Φιλμ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Μαύρο-Λευκό</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Φλασχλιτ</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ενεργό</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Απενεργό</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Καθυστέρηση αποτύπωσης</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Φίλτρα</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Εκτίμηση</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Δεν βρέθηκε κάμερα</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Η κάμερα είναι σε χρήση</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Λήξη εγγραφής</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.33.tar.xz: BUILD/src/translations/deepin-camera_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Η εγγραφή βίντεο είναι σε εξέλιξη. Να κλείσει το παράθυρο;</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Φωτογραφία</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Αλλαγή καμερών</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Δεν έχετε άδεια πρόσβασης στον φάκελο</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Μη έγκυρος φάκελος</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Άνοιγμα φακέλου</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Βασικό</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Τοποθεσία φακέλου</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Λήψη</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Γρήγορη λειτουργία</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Χρονοκαθυστέρηση</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Φορμά Εξόδου</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 τμχ</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 τμχ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Το Camera είναι ένα εργαλείο λήψης και εγγραφής φωτογραφιών και βίντεο, με τη χρήση της κάμερας του υπολογιστή σας.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Το αρχείο δεν αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Αποθήκευση σε:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Φωτογραφία:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ρυθμίσεις ανάλυσεις</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ανάλυση:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Φωτογραφίες:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Βίντεο:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Ήχοι επίδρασης</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Λευκός κατακόρυφος</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Φλασχλίτσα</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Γραμμές περιοχής</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Γραμμές 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Γραμμές 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Μέγιστη ανάλυση:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Κάμερα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Λήξη εγγραφής</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Εμφάνιση συντομεύσεων</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Ακύρωση λήψης φωτογραφιών</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Μενού πεδίου</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Λήψη φωτογραφίας</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Εγγραφή βίντεο</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Ακύρωση λήψης φωτογραφιών</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Κανονική</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Ζωντανή</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Θερμή</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Ψυχρή</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Αντίστροφη</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Φιλμ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Γκρι</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Μαύρο-Πίνακας</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Φλασχλίτσα</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ενεργός</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Αποστολή με καθυστέρηση</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Φίλτρα</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Εξομάλυνση</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Δεν βρέθηκε κάμερα</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Η κάμερα είναι σε χρήση</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Λήξη εγγραφής</translation>
    </message>
</context>
</TS>
